==> aliyun-python-sdk-openanalytics-open-2.0.2.tar.gz: aliyun-python-sdk-openanalytics-open-2.0.2/aliyunsdkopenanalytics_open/request/v20180619/AddEndPointRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkopenanalytics_open.endpoint import endpoint_data

class AddEndPointRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'openanalytics-open', '2018-06-19', 'AddEndPoint','openanalytics')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Product(self):
		return self.get_body_params().get('Product')

	def set_Product(self,Product):
		self.add_body_params('Product', Product)

	def get_NetworkType(self):
		return self.get_body_params().get('NetworkType')

	def set_NetworkType(self,NetworkType):
		self.add_body_params('NetworkType', NetworkType)

	def get_Vswitch(self):
		return self.get_body_params().get('Vswitch')

	def set_Vswitch(self,Vswitch):
		self.add_body_params('Vswitch', Vswitch)

	def get_Zone(self):
		return self.get_body_params().get('Zone')

	def set_Zone(self,Zone):
		self.add_body_params('Zone', Zone)

	def get_VpcID(self):
		return self.get_body_params().get('VpcID')

	def set_VpcID(self,VpcID):
		self.add_body_params('VpcID', VpcID)

==> aliyun-python-sdk-openanalytics-open-2.0.4.tar.gz: aliyun-python-sdk-openanalytics-open-2.0.4/aliyunsdkopenanalytics_open/request/v20180619/AddEndPointRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkopenanalytics_open.endpoint import endpoint_data

class AddEndPointRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'openanalytics-open', '2018-06-19', 'AddEndPoint','openanalytics-cap')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Product(self):
		return self.get_body_params().get('Product')

	def set_Product(self,Product):
		self.add_body_params('Product', Product)

	def get_NetworkType(self):
		return self.get_body_params().get('NetworkType')

	def set_NetworkType(self,NetworkType):
		self.add_body_params('NetworkType', NetworkType)

	def get_Vswitch(self):
		return self.get_body_params().get('Vswitch')

	def set_Vswitch(self,Vswitch):
		self.add_body_params('Vswitch', Vswitch)

	def get_Zone(self):
		return self.get_body_params().get('Zone')

	def set_Zone(self,Zone):
		self.add_body_params('Zone', Zone)

	def get_VpcID(self):
		return self.get_body_params().get('VpcID')

	def set_VpcID(self,VpcID):
		self.add_body_params('VpcID', VpcID)
